@@ -13,8 +13,12 @@ my $arg  = join('', @ARGV);
 my $new_x;
 my $new_y;
 my $F;
+my $dev = 0;
 
 $file = 1 if ($arg =~ /file/i);    # File Handle drawing mode
+if ($arg =~ /(\d+)/) {
+    $dev = $1;
+}
 
 if ($arg =~ /X(\d+)/) {
     $new_x = $1;
@@ -24,9 +28,9 @@ if ($arg =~ /Y(\d+)/) {
 }
 
 if (defined($new_x)) {
-    $F = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
+    $F = Graphics::Framebuffer->new('FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1, 'SIMULATED_X' => $new_x,'SIMULATED_Y' => $new_y);
 } else {
-    $F = Graphics::Framebuffer->new('FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
+    $F = Graphics::Framebuffer->new('SPLASH' => 0,'FB_DEVICE' => "/dev/fb$dev",'FILE_MODE' => $file, 'SHOW_ERRORS' => 1);
 }
 
 $SIG{'QUIT'} = sub {$F->clip_reset();$F->cls('ON'); exit(0);};
@@ -206,25 +210,25 @@ print_it($F, 'Poly Arc Test');
 $s = time + $factor;
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->poly_arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
+    $F->poly_arc({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Filled Pie Test');
-$s = time + $factor;
+$s = time + ($factor * 2);
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
-    $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_x), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
+    $F->filled_pie({'x' => rand($XX), 'y' => rand($YY), 'radius' => rand($center_y), 'start_degrees' => rand(360), 'end_degrees' => rand(360)});
 }
 
 print_it($F, 'Gradient Filled Pie Test');
-$s = time + $factor;
+$s = time + ($factor * 2);
 while (time < $s) {
     $F->set_color({'red' => rand(256), 'green' => rand(256), 'blue' => rand(256)});
     $F->filled_pie(
         {
             'x'             => rand($XX),
             'y'             => rand($YY),
-            'radius'        => rand($center_x),
+            'radius'        => rand($center_y),
             'start_degrees' => rand(360),
             'end_degrees'   => rand(360),
             'gradient'      => {
